Index: generic/include/adt/btree.h
===================================================================
--- generic/include/adt/btree.h	(revision 2a1fa51536bfc1c1cff6d27d507dc0e67b239201)
+++ generic/include/adt/btree.h	(revision c47912f7cc3fc6625772f9dd1370d20d9bb36539)
@@ -84,6 +84,6 @@
 extern void *btree_search(btree_t *t, __native key, btree_node_t **leaf_node);
 
-extern btree_node_t *btree_node_left_sibling(btree_t *t, btree_node_t *node);
-extern btree_node_t *btree_node_right_sibling(btree_t *t, btree_node_t *node);
+extern btree_node_t *btree_leaf_node_left_neighbour(btree_t *t, btree_node_t *node);
+extern btree_node_t *btree_leaf_node_right_neighbour(btree_t *t, btree_node_t *node);
 
 extern void btree_print(btree_t *t);
Index: generic/src/adt/btree.c
===================================================================
--- generic/src/adt/btree.c	(revision 2a1fa51536bfc1c1cff6d27d507dc0e67b239201)
+++ generic/src/adt/btree.c	(revision c47912f7cc3fc6625772f9dd1370d20d9bb36539)
@@ -341,12 +341,12 @@
 }
 
 /** Return pointer to B-tree node's left sibling.
  *
  * @param t B-tree.
- * @param node Node whose left sibling will be returned.
- *
- * @return Left sibling of the node or NULL if the node does not have the left sibling.
- */
-btree_node_t *btree_node_left_sibling(btree_t *t, btree_node_t *node)
+ * @param node Node whose left neighbour will be returned.
+ *
+ * @return Left neighbour of the node or NULL if the node does not have the left neighbour.
+ */
+btree_node_t *btree_leaf_node_left_neighbour(btree_t *t, btree_node_t *node)
 {
 	ASSERT(LEAF_NODE(node));
@@ -357,12 +357,12 @@
 }
 
 /** Return pointer to B-tree node's right sibling.
  *
  * @param t B-tree.
- * @param node Node whose right sibling will be returned.
- *
- * @return Right sibling of the node or NULL if the node does not have the right sibling.
- */
-btree_node_t *btree_node_right_sibling(btree_t *t, btree_node_t *node)
+ * @param node Node whose right neighbour will be returned.
+ *
+ * @return Right neighbour of the node or NULL if the node does not have the right neighbour.
+ */
+btree_node_t *btree_leaf_node_right_neighbour(btree_t *t, btree_node_t *node)
 {
 	ASSERT(LEAF_NODE(node));
@@ -341,12 +341,12 @@
 }
 
-/** Return pointer to B-tree node's left sibling.
+/** Return pointer to B-tree leaf node's left neighbour.
  *
  * @param t B-tree.
@@ -357,12 +357,12 @@
 }
 
-/** Return pointer to B-tree node's right sibling.
+/** Return pointer to B-tree leaf node's right neighbour.
  *
  * @param t B-tree.
Index: generic/src/mm/as.c
===================================================================
--- generic/src/mm/as.c	(revision 2a1fa51536bfc1c1cff6d27d507dc0e67b239201)
+++ generic/src/mm/as.c	(revision c47912f7cc3fc6625772f9dd1370d20d9bb36539)
@@ -526,5 +526,5 @@
 	
 	/*
 	 * Search the leaf node and the righmost record of its left sibling
 	 * to find out whether this is a miss or va belongs to an address
 	 * space area found there.
@@ -542,8 +542,8 @@
 
 	/*
 	 * Second, locate the left sibling and test its last record.
 	 * Because of its position in the B+tree, it must have base < va.
 	 */
-	if ((lnode = btree_node_left_sibling(&as->as_area_btree, leaf))) {
+	if ((lnode = btree_leaf_node_left_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) lnode->value[lnode->keys - 1];
 		spinlock_lock(&a->lock);
@@ -584,6 +584,6 @@
 	 * the number of address space areas belonging to as.
 	 * The check for conflicts is then attempted on the rightmost
 	 * record in the left sibling, the leftmost record in the right
 	 * sibling and all records in the leaf node itself.
 	 */
 	
@@ -594,5 +594,5 @@
 	
 	/* First, check the two border cases. */
-	if ((node = btree_node_left_sibling(&as->as_area_btree, leaf))) {
+	if ((node = btree_leaf_node_left_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) node->value[node->keys - 1];
 		spinlock_lock(&a->lock);
@@ -603,5 +603,5 @@
 		spinlock_unlock(&a->lock);
 	}
-	if ((node = btree_node_right_sibling(&as->as_area_btree, leaf))) {
+	if ((node = btree_leaf_node_right_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) node->value[0];
 		spinlock_lock(&a->lock);
@@ -526,5 +526,5 @@
 	
 	/*
-	 * Search the leaf node and the righmost record of its left sibling
+	 * Search the leaf node and the righmost record of its left neighbour
 	 * to find out whether this is a miss or va belongs to an address
 	 * space area found there.
@@ -542,8 +542,8 @@
 
 	/*
-	 * Second, locate the left sibling and test its last record.
+	 * Second, locate the left neighbour and test its last record.
 	 * Because of its position in the B+tree, it must have base < va.
 	 */
@@ -584,6 +584,6 @@
 	 * the number of address space areas belonging to as.
 	 * The check for conflicts is then attempted on the rightmost
-	 * record in the left sibling, the leftmost record in the right
-	 * sibling and all records in the leaf node itself.
+	 * record in the left neighbour, the leftmost record in the right
+	 * neighbour and all records in the leaf node itself.
 	 */
 	
